#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_INSERT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_INSERT_HPP_INCLUDED

#include <boost/simd/memory/include/functions/insert.hpp>

#endif
